% TRANPAREA - Belarus

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


DATA = load('data_BY');


%% ****************************  data transformations  ****************************

% DATA.DEB_THEFT(DATA.DEB_THEFT==6) = 3;
% DATA.DEB_RESP(DATA.DEB_RESP==6) = 3;
% DATA.DEB_PAT(DATA.DEB_PAT==6) = 3;
% DATA.DEB_FREER(DATA.DEB_FREER==6) = 3;
% % DATA.DEB_AREA(DATA.DEB_AREA==6) = 3;
% DATA.DEB_POP(DATA.DEB_POP==6) = 3;
% DATA.DEB_WEALTH(DATA.DEB_WEALTH==6) = 3;
% DATA.DEB_TAX(DATA.DEB_TAX==6) = 3;
% DATA.DEB_POLIT(DATA.DEB_POLIT==6) = 3;
% DATA.DEB_BY5(DATA.DEB_BY5==6) = 3;
% DATA.DEB_PL5(DATA.DEB_PL5==6) = 3;

DATA.DEB_THEFT(DATA.DEB_THEFT==6) = NaN;
DATA.DEB_RESP(DATA.DEB_RESP==6) = NaN;
DATA.DEB_PAT(DATA.DEB_PAT==6) = NaN;
DATA.DEB_FREER(DATA.DEB_FREER==6) = NaN;
% DATA.DEB_AREA(DATA.DEB_AREA==6) = 3;
DATA.DEB_POP(DATA.DEB_POP==6) = NaN;
DATA.DEB_WEALTH(DATA.DEB_WEALTH==6) = NaN;
DATA.DEB_TAX(DATA.DEB_TAX==6) = NaN;
DATA.DEB_POLIT(DATA.DEB_POLIT==6) = NaN;
DATA.DEB_BY5(DATA.DEB_BY5==6) = NaN;
DATA.DEB_PL5(DATA.DEB_PL5==6) = NaN;

%% ****************************  model specification  ****************************


DATA.Y = DATA.CHOICE;

% DATA.Xa = [(DATA.ALTIDX==1), DATA.SBY_35, DATA.SBY_70, DATA.SBY_105, DATA.SPL_35, DATA.SPL_70, DATA.SPL_105, -DATA.BID.*0.40348014/10];
% EstimOpt.NamesA = {'SQ','BY +35 km2','BY +70 km2','BY +105 km2','PL +35 km2','PL +70 km2','PL +105 km2','-COST (10 EUR PPP)'};
% EstimOpt.ProjectName = 'tranparea_BY';

DATA.Xa = [DATA.SQ, (DATA.S_BY+DATA.S_PL)/100, DATA.S_PL/100, -DATA.BID.*2.08144121/10];
EstimOpt.NamesA = {'SQ','Total extension (100 km2)','Extension abroad (100 km2)','-COST (10 EUR PPP)'};
EstimOpt.ProjectName = 'BY_simple';


%% ****************************  specifying input ****************************


DATA.filter = true(size(DATA.CHOICE));
% DATA.filter = (DATA.WSQ ~= 5 & DATA.WSQ ~= 1);
DATA.filter = reshape((repmat((~(DATA.WSQ(DATA.ALTIDX==1)==5 | DATA.WSQ(DATA.ALTIDX==1)==1)),[1,4]))',size(DATA.CHOICE));


INPUT.Y = DATA.CHOICE(DATA.filter);
INPUT.Xa = DATA.Xa(DATA.filter,:);

INPUT.MissingInd = DATA.Missing(DATA.filter);


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 16; % Number of choice tasks per person
EstimOpt.NAlt = 4; % Number of alternatives
EstimOpt.NP = size(INPUT.Y,1)./EstimOpt.NCT./EstimOpt.NAlt; % Number of respondents


%% **************************** estimation and optimization options ****************************

% EstimOpt.eps = 1.e-6; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 100; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'off'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 1; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian
% EstimOpt.ApproxHess = 0;


%% ****************************     MNL     ****************************


EstimOpt.WTP_space = 1;

Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     MXL_d     ****************************


% simple: -9739.5025
B_backup = [5.26548971850598;0.780094860297029;-3.72862271702619;-2.27180763946254;23.9401742782945;3.43327346860761;2.18078240101674;0.572064584273395];

OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     HMXL_d     ****************************


EstimOpt.NLatent = 8;
    
INPUT.Xmea = [DATA.DEB_PL5, DATA.DEB_BY5, ...
    DATA.DEB_POP, DATA.DEB_WEALTH, ...
    DATA.DEB_THEFT, DATA.DEB_RESP, ...
    DATA.DEB_FREER, ...
    DATA.DEB_PAT];
INPUT.Xmea(isnan(INPUT.Xmea(INPUT.MissingInd==0))) = 3;
EstimOpt.NamesMea = {'Intend to visit PL', 'Intend to visit BY',...
    'PL more - population', 'PL more - wealth',...
    'PL misuse money', 'BY will comply more',...
    'PL extend anyway', ...
    'BY more - national'};
EstimOpt.MeaMatrix = [1 0 0 0 0 0 0 0; ...
    0 1 0 0 0 0 0 0; ...
    0 0 1 0 0 0 0 0; ...
    0 0 0 1 0 0 0 0; ...
    0 0 0 0 1 0 0 0; ...
    0 0 0 0 0 1 0 0; ...
    0 0 0 0 0 0 1 0; ...
    0 0 0 0 0 0 0 1];
EstimOpt.MeaSpecMatrix = [2];

INPUT.Xmea = INPUT.Xmea(DATA.filter,:);

EstimOpt.BActive = [];
    
EstimOpt.FullCov = 0;

B_backup = [4.0343062887420568785;0.65905577575035445559;-3.925398378762786411;-2.2605780163426012486;23.337227530579390589;3.8924765101693985514;1.8714636382139484549;0.60061231843784146367;0;0;1.417319262270475777;0;0;0;-2.0537629180757157599;0;0;0;-1.37916943577069806;0;0;0;0.57717077781755465882;0;0;0;0.41529349618952760004;0;0;0;0.18711922301298661298;0;0;0;-0.58958147685085726675;0;0;0;-0.29104650058442349536;0;-0.066759454704173076811;-0.48757879708338752733;-0.62344540294426120663;-0.015949264028002868576;-0.44629802221455644462;-0.76505593352195511159;-1.4257063534905691782;-0.55965519109518913066;-1.0012270687895297172;0.11407578269879092847;4.2855023218334364898;-5.9945765981692762381;1.0189207000784807899;0.70424870629892311058;1.5487382123011494972;0.79279465736283472044;-1.9529910555598459787;-0.16044699974278847643;-0.61023388494094166212;0.39444039736440167365;-1.9520882978348839121;-2.6105781520669864015;0.59303232272959938154;-0.042614629275346448123;0.55994757072944745246;-8.9725169410049794294;-13.626145909979397786;2.0230536350190977402;1.6705126176745248578;2.2851249449158257399;-0.25453804552896092117;-1.8787816961976078201;-0.2551581442622588014;-0.49880513828918326968;0.44812343132446752492;-0.78555674070470304926;-1.393301874603181556;-0.35888536692315020638;-0.64174343384623599995;0.23118420408114798148];
EstimOpt.BActive = ones(size(B_backup));
EstimOpt.BActive([9,10,12, 13,14,16, 17,18,20, 21,22,24, 25,26,28, 29,30,32, 33,34,36, 37,38,40]) = 0;
B_backup = B_backup .* EstimOpt.BActive;

EstimOpt.RealMin = 1;
    
OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);
