% TRANPAREA - Norway

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


DATA = load('data_NO.mat');


%% ****************************  data transformations  ****************************

% DATA.DEB_THEFT(DATA.DEB_THEFT==6 | DATA.DEB_THEFT==0) = 3;
% DATA.DEB_RESP(DATA.DEB_RESP==6 | DATA.DEB_RESP==0) = 3;
% DATA.DEB_PAT(DATA.DEB_PAT==6 | DATA.DEB_PAT==0) = 3;
% DATA.DEB_FREER(DATA.DEB_FREER==6 | DATA.DEB_FREER==0) = 3;
% DATA.DEB_POP(DATA.DEB_POP==6 | DATA.DEB_POP==0) = 3;
% DATA.DEB_WEALTH(DATA.DEB_WEALTH==6 | DATA.DEB_WEALTH==0) = 3;
% DATA.DEB_POLIT(DATA.DEB_POLIT==6 | DATA.DEB_POLIT==0) = 3;
% DATA.DEB_TAX(DATA.DEB_TAX==6 | DATA.DEB_TAX==0) = 3;
% % DATA.DEB_BID(DATA.DEB_BID==6 | DATA.DEB_BID==0) = 3;
% DATA.DEB_NO5(DATA.DEB_NO5==6 | DATA.DEB_NO5==0) = 3;
% DATA.DEB_SE5(DATA.DEB_SE5==6 | DATA.DEB_SE5==0) = 3;

DATA.DEB_THEFT(DATA.DEB_THEFT==6 | DATA.DEB_THEFT==0) = NaN;
DATA.DEB_RESP(DATA.DEB_RESP==6 | DATA.DEB_RESP==0) = NaN;
DATA.DEB_PAT(DATA.DEB_PAT==6 | DATA.DEB_PAT==0) = NaN;
DATA.DEB_FREER(DATA.DEB_FREER==6 | DATA.DEB_FREER==0) = NaN;
DATA.DEB_POP(DATA.DEB_POP==6 | DATA.DEB_POP==0) = NaN;
DATA.DEB_WEALTH(DATA.DEB_WEALTH==6 | DATA.DEB_WEALTH==0) = NaN;
DATA.DEB_POLIT(DATA.DEB_POLIT==6 | DATA.DEB_POLIT==0) = NaN;
DATA.DEB_TAX(DATA.DEB_TAX==6 | DATA.DEB_TAX==0) = NaN;
% DATA.DEB_BID(DATA.DEB_BID==6 | DATA.DEB_BID==0) = 3;
DATA.DEB_NO5(DATA.DEB_NO5==6 | DATA.DEB_NO5==0) = NaN;
DATA.DEB_SE5(DATA.DEB_SE5==6 | DATA.DEB_SE5==0) = NaN;

%% ****************************  model specification  ****************************


DATA.Y = DATA.CHOICE;

% DATA.Xa = [DATA.SQ, DATA.SNO_20, DATA.SNO_40, DATA.SNO_60, DATA.SSE_20, DATA.SSE_40, DATA.SSE_60, -DATA.BID.*0.06927369/10];
% EstimOpt.NamesA = {'SQ','NO +20 km2','NO +40 km2','NO +60 km2','SE +20 km2','SE +40 km2','SE +60 km2','COST (10 EUR PPP)'};
% EstimOpt.ProjectName = 'tranparea_NO';

DATA.Xa = [DATA.SQ, (DATA.S_NO+DATA.S_SE)/100, DATA.S_SE/100, -DATA.BID.*0.06927369/10];
EstimOpt.NamesA = {'SQ','Total extension (100 km2)','Extension abroad (100 km2)','-COST (10 EUR PPP)'};
EstimOpt.ProjectName = 'NO_simple';


%% ****************************  specifying input ****************************


DATA.filter = true(size(DATA.CHOICE));
DATA.filter = (DATA.WSQ ~= 5 & DATA.WSQ ~= 1);

INPUT.Y = DATA.CHOICE(DATA.filter);
INPUT.Xa = DATA.Xa(DATA.filter,:);

INPUT.MissingInd = DATA.Missing(DATA.filter);


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 16; % Number of choice tasks per person
EstimOpt.NAlt = 4; % Number of alternatives
EstimOpt.NP = size(INPUT.Y,1)./EstimOpt.NCT./EstimOpt.NAlt; % Number of respondents


%% **************************** estimation and optimization options ****************************


% EstimOpt.eps = 1.e-6; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 100; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'off'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 1; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian
% EstimOpt.ApproxHess = 0;


%% ****************************     MNL     ****************************


EstimOpt.WTP_space = 1;
Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     MXL_d     ****************************


% simple:
B_backup = [-2.74390234201747;3.57295822404673;-3.20115883102660;0.0464545610824853;5.16182922336180;5.29016351950176;3.01619561251284;1.07166170496563];

OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     HMXL_d     ****************************


EstimOpt.NLatent = 8;

INPUT.Xmea = [DATA.DEB_NO5, DATA.DEB_SE5, ...
    DATA.DEB_POP, DATA.DEB_WEALTH, ...
    DATA.DEB_THEFT, DATA.DEB_RESP, ...
    DATA.DEB_FREER, ...
    DATA.DEB_PAT];
%     INPUT.Xmea(isnan(INPUT.Xmea(INPUT.MissingInd==0))) = 3;
EstimOpt.NamesMea = {'Intend to visit NO', 'Intend to visit SE',...
    'SE more - population', 'NO more - wealth',...
    'NO misuse money', 'SE will comply more',...
    'NO extend anyway', ...
    'SE more - national'};
EstimOpt.MeaMatrix = [1 0 0 0 0 0 0 0; ...
    0 1 0 0 0 0 0 0; ...
    0 0 1 0 0 0 0 0; ...
    0 0 0 1 0 0 0 0; ...
    0 0 0 0 1 0 0 0; ...
    0 0 0 0 0 1 0 0; ...
    0 0 0 0 0 0 1 0; ...
    0 0 0 0 0 0 0 1];
EstimOpt.MeaSpecMatrix = [2];

INPUT.Xmea = INPUT.Xmea(DATA.filter,:);

EstimOpt.FullCov = 0;

B_backup = [-2.3619620033807517956;3.8114138643414139374;-3.1394135726238769912;0.05306240710947428274;5.3070460468131672727;4.7803435929938764559;1.1783051384661700212;1.0988678945678582721;0;0;1.5300021951629347861;0;0;0;-2.4034485353434176247;0;0;0;-0.20380882723929974465;0;0;0;1.4627420692655670464;0;0;0;0.31154102152477636256;0;0;0;0.30132411775076534122;0;0;0;0.6134598808542499615;0;0;0;1.1090286667326394454;0;-3.490258095952424533;-0.91348071128195273971;0.2535701958894426844;0.88440313886959442957;0.92521927699751527197;-0.66813632043384396653;-0.043673914112286021938;-0.89227361466131438483;-0.063060668624677615468;-0.38065997323149242115;-0.89704322953516002492;-1.6641905049323570953;-0.34843017788950014779;0.20954072934060369304;0.041340412253732347625;0.26633098767048035693;-0.33737283338142037836;-0.61114089973087981633;-0.069069543163446947553;-0.29924153803358688464;-0.41186184792224711515;-0.92306366677463591586;-0.37147780559669096867;0.084414186316930428511;-0.31555088939836861694;-0.19114517890004872891;-1.5468065795987520072;-0.50147383945233525715;0.25417767059129403595;-0.43342574816913442826;-0.023002724781848751107;-1.9105196459310282986;-1.026978352789623683;0.50465867177704792912;-0.46125957924954807954;-0.077109043204339908217;-1.3501281215416089942;-0.74643055229416577223;-0.14846530272684704821;-0.1942488701500940107];
EstimOpt.BActive = ones(size(B_backup));
EstimOpt.BActive([9,10,12, 13,14,16, 17,18,20, 21,22,24, 25,26,28, 29,30,32, 33,34,36, 37,38,40]) = 0;
B_backup = B_backup .* EstimOpt.BActive;

EstimOpt.RealMin = 1;

OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);
