% TRANPAREA - Poland

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


DATA = load('data_PL');


%% ****************************  data transformations  ****************************

% DATA.DEB_THEFT(DATA.DEB_THEFT==6) = 3;
% DATA.DEB_RESP(DATA.DEB_RESP==6) = 3;
% DATA.DEB_PAT(DATA.DEB_PAT==6) = 3;
% DATA.DEB_FREER(DATA.DEB_FREER==6) = 3;
% % DATA.DEB_AREA(DATA.DEB_AREA==6) = 3;
% DATA.DEB_POP(DATA.DEB_POP==6) = 3;
% DATA.DEB_WEALTH(DATA.DEB_WEALTH==6) = 3;
% DATA.DEB_TAX(DATA.DEB_TAX==6) = 3;
% DATA.DEB_POLIT(DATA.DEB_POLIT==6) = 3;
% DATA.DEB_BY5(DATA.DEB_BY5==6) = 3;
% DATA.DEB_PL5(DATA.DEB_PL5==6) = 3;

DATA.DEB_THEFT(DATA.DEB_THEFT==6) = NaN;
DATA.DEB_RESP(DATA.DEB_RESP==6) = NaN;
DATA.DEB_PAT(DATA.DEB_PAT==6) = NaN;
DATA.DEB_FREER(DATA.DEB_FREER==6) = NaN;
% DATA.DEB_AREA(DATA.DEB_AREA==6) = 3;
DATA.DEB_POP(DATA.DEB_POP==6) = NaN;
DATA.DEB_WEALTH(DATA.DEB_WEALTH==6) = NaN;
DATA.DEB_TAX(DATA.DEB_TAX==6) = NaN;
DATA.DEB_POLIT(DATA.DEB_POLIT==6) = NaN;
DATA.DEB_BY5(DATA.DEB_BY5==6) = NaN;
DATA.DEB_PL5(DATA.DEB_PL5==6) = NaN;

%% ****************************  model specification  ****************************


DATA.Y = DATA.CHOICE;

% DATA.Xa = [(DATA.ALTIDX==1), DATA.SBY_35, DATA.SBY_70, DATA.SBY_105, DATA.SPL_35, DATA.SPL_70, DATA.SPL_105, -DATA.BID.*0.40348014/10];
% EstimOpt.NamesA = {'SQ','BY +35 km2','BY +70 km2','BY +105 km2','PL +35 km2','PL +70 km2','PL +105 km2','-COST (10 EUR PPP)'};
% EstimOpt.ProjectName = 'tranparea_PL';

DATA.Xa = [DATA.SQ, (DATA.S_BY+DATA.S_PL)/100, DATA.S_BY/100, -DATA.BID.*0.40348014/10];
EstimOpt.NamesA = {'SQ','Total extension (100 km2)','Extension abroad (100 km2)','-COST (10 EUR PPP)'};
EstimOpt.ProjectName = 'PL_simple';


%% ****************************  specifying input ****************************


DATA.filter = true(size(DATA.CHOICE));
% DATA.filter = (DATA.WSQ ~= 5 & DATA.WSQ ~= 1);
DATA.filter = reshape((repmat((~(DATA.WSQ(DATA.ALTIDX==1)==5 | DATA.WSQ(DATA.ALTIDX==1)==1)),[1,4]))',size(DATA.CHOICE));


INPUT.Y = DATA.CHOICE(DATA.filter);
INPUT.Xa = DATA.Xa(DATA.filter,:);

INPUT.MissingInd = DATA.Missing(DATA.filter);


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 16; % Number of choice tasks per person
EstimOpt.NAlt = 4; % Number of alternatives
EstimOpt.NP = size(INPUT.Y,1)./EstimOpt.NCT./EstimOpt.NAlt; % Number of respondents


%% **************************** estimation and optimization options ****************************

% EstimOpt.eps = 1.e-6; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 100; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'off'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 1; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian
% EstimOpt.ApproxHess = 0;


%% ****************************     MNL     ****************************


EstimOpt.WTP_space = 1;

Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     MXL_d     ****************************


% simple: -7003.6448
B_backup = [-1.41139893311135;1.00622631783990;-1.63584509816288;0.763213514777309;2.08342373621756;1.70307606472821;1.73685402911767;1.31342105538597];

OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     HMXL_d     ****************************


EstimOpt.NLatent = 8;

INPUT.Xmea = [DATA.DEB_PL5, DATA.DEB_BY5, ...
    DATA.DEB_POP, DATA.DEB_WEALTH, ...
    DATA.DEB_THEFT, DATA.DEB_RESP, ...
    DATA.DEB_FREER, ...
    DATA.DEB_PAT];
EstimOpt.NamesMea = {'Intend to visit PL', 'Intend to visit BY',...
    'PL more - population', 'PL more - wealth',...
    'BY misuse money', 'BY won''t comply',...
    'BY extend anyway', ...
    'PL more - national'};
EstimOpt.MeaMatrix = [1 0 0 0 0 0 0 0; ...
    0 1 0 0 0 0 0 0; ...
    0 0 1 0 0 0 0 0; ...
    0 0 0 1 0 0 0 0; ...
    0 0 0 0 1 0 0 0; ...
    0 0 0 0 0 1 0 0; ...
    0 0 0 0 0 0 1 0; ...
    0 0 0 0 0 0 0 1];
EstimOpt.MeaSpecMatrix = [2];

INPUT.Xmea = INPUT.Xmea(DATA.filter,:);

EstimOpt.BActive = [];

EstimOpt.FullCov = 0;

B_backup = [-1.1863936151292135968;0.8100159302560846486;-1.4761390114132448836;0.74339536228005975715;2.4048971350289942706;1.5808751669470322287;0.48723630726156613724;1.2923693853728603909;0;0;0.94457242872305691161;0;0;0;-0.60910613192101137336;0;0;0;-0.04938522467448652753;0;0;0;-0.34514206638887207079;0;0;0;0.06137634855341076584;0;0;0;-0.77679094314073415806;0;0;0;-0.46730941911909723574;0;0;0;0.59701345726712296003;0;-0.18516360231222792065;-1.1719835422058162422;-0.37019459087453671087;-0.57193879456064045108;0.10736601055416811201;-1.2127340313551224771;-0.79695205082660847129;0.13958425315693717694;-0.4489985994625657062;0.40734657267637469635;-0.41520736227722615519;-2.3602505157295796678;0.09820592992580901015;-0.14636090020784695009;0.21161950850843774807;-0.15307156629551596505;-1.1439531568136254158;-0.10932776505693950209;-0.274710725674727263;-0.11050680043783617235;-0.014118535791687595454;-2.070026098153683769;0.017919944140045624553;-0.35128344796499366698;0.13469622335087202969;0.0076364454490646460974;-1.9950625318931582974;-0.21080195833136447514;-0.28011130394120098419;0.11830580404877050205;0.80519613725390182246;-2.7166025070747448211;-0.011441775399824948706;0.18826295356999717123;0.52464879645123962959;-0.14749169623220997893;-1.7131662206723403674;-0.36049138191155150057;-0.4972630915582898492;0.010576005871886779222];
EstimOpt.BActive = ones(size(B_backup));
EstimOpt.BActive([9,10,12, 13,14,16, 17,18,20, 21,22,24, 25,26,28, 29,30,32, 33,34,36, 37,38,40]) = 0;
B_backup = B_backup .* EstimOpt.BActive;

EstimOpt.RealMin = 1;

OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);
