% TRANPAREA - Sweden

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


DATA = load('data_SE.mat');


%% ****************************  data transformations  ****************************

% DATA.DEB_THEFT(DATA.DEB_THEFT==6 | DATA.DEB_THEFT==0) = 3;
% DATA.DEB_RESP(DATA.DEB_RESP==6 | DATA.DEB_RESP==0) = 3;
% DATA.DEB_PAT(DATA.DEB_PAT==6 | DATA.DEB_PAT==0) = 3;
% DATA.DEB_FREER(DATA.DEB_FREER==6 | DATA.DEB_FREER==0) = 3;
% DATA.DEB_POP(DATA.DEB_POP==6 | DATA.DEB_POP==0) = 3;
% DATA.DEB_WEALTH(DATA.DEB_WEALTH==6 | DATA.DEB_WEALTH==0) = 3;
% DATA.DEB_POLIT(DATA.DEB_POLIT==6 | DATA.DEB_POLIT==0) = 3;
% DATA.DEB_TAX(DATA.DEB_TAX==6 | DATA.DEB_TAX==0) = 3;
% % DATA.DEB_BID(DATA.DEB_BID==6 | DATA.DEB_BID==0) = 3;
% DATA.DEB_NO5(DATA.DEB_NO5==6 | DATA.DEB_NO5==0) = 3;
% DATA.DEB_SE5(DATA.DEB_SE5==6 | DATA.DEB_SE5==0) = 3;

DATA.DEB_THEFT(DATA.DEB_THEFT==6 | DATA.DEB_THEFT==0) = NaN;
DATA.DEB_RESP(DATA.DEB_RESP==6 | DATA.DEB_RESP==0) = NaN;
DATA.DEB_PAT(DATA.DEB_PAT==6 | DATA.DEB_PAT==0) = NaN;
DATA.DEB_FREER(DATA.DEB_FREER==6 | DATA.DEB_FREER==0) = NaN;
DATA.DEB_POP(DATA.DEB_POP==6 | DATA.DEB_POP==0) = NaN;
DATA.DEB_WEALTH(DATA.DEB_WEALTH==6 | DATA.DEB_WEALTH==0) = NaN;
DATA.DEB_POLIT(DATA.DEB_POLIT==6 | DATA.DEB_POLIT==0) = NaN;
DATA.DEB_TAX(DATA.DEB_TAX==6 | DATA.DEB_TAX==0) = NaN;
% DATA.DEB_BID(DATA.DEB_BID==6 | DATA.DEB_BID==0) = 3;
DATA.DEB_NO5(DATA.DEB_NO5==6 | DATA.DEB_NO5==0) = NaN;
DATA.DEB_SE5(DATA.DEB_SE5==6 | DATA.DEB_SE5==0) = NaN;

%% ****************************  model specification  ****************************


DATA.Y = DATA.CHOICE;

% DATA.Xa = [DATA.SQ, DATA.SNO_20, DATA.SNO_40, DATA.SNO_60, DATA.SSE_20, DATA.SSE_40, DATA.SSE_60, -DATA.BID.*0.08353853/10];
% EstimOpt.NamesA = {'SQ','NO +20 km2','NO +40 km2','NO +60 km2','SE +20 km2','SE +40 km2','SE +60 km2','COST (10 EUR PPP)'};
% EstimOpt.ProjectName = 'tranparea_SE';

DATA.Xa = [DATA.SQ, (DATA.S_NO+DATA.S_SE)/100, DATA.S_NO/100, -DATA.BID.*0.08353853/10];
EstimOpt.NamesA = {'SQ','Total extension (100 km2)','Extension abroad (100 km2)','-COST (10 EUR PPP)'};
EstimOpt.ProjectName = 'SE_simple';


%% ****************************  specifying input ****************************


DATA.filter = true(size(DATA.CHOICE));
DATA.filter = (DATA.WSQ ~= 5 & DATA.WSQ ~= 1);

INPUT.Y = DATA.CHOICE(DATA.filter);
INPUT.Xa = DATA.Xa(DATA.filter,:);

INPUT.MissingInd = DATA.Missing(DATA.filter);


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 16; % Number of choice tasks per person
EstimOpt.NAlt = 4; % Number of alternatives
EstimOpt.NP = size(INPUT.Y,1)./EstimOpt.NCT./EstimOpt.NAlt; % Number of respondents


%% **************************** estimation and optimization options ****************************

% EstimOpt.eps = 1.e-6; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 100; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'off'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 1; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian
% EstimOpt.ApproxHess = 0;


%% ****************************     MNL     ****************************

EstimOpt.WTP_space = 1;

Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     MXL_d     ****************************


% simple: 
B_backup = [-2.87041240455019;3.07229503406556;-2.07873042201642;0.0787760690733798;6.45366429965438;4.25913133768743;2.47187449401133;1.25297802061027];

OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     HMXL_d     ****************************


EstimOpt.NLatent = 8;

INPUT.Xmea = [DATA.DEB_NO5, DATA.DEB_SE5, ...
    DATA.DEB_POP, DATA.DEB_WEALTH, ...
    DATA.DEB_THEFT, DATA.DEB_RESP, ...
    DATA.DEB_FREER, ...
    DATA.DEB_PAT];
INPUT.Xmea(isnan(INPUT.Xmea(INPUT.MissingInd==0))) = 3;
EstimOpt.NamesMea = {'Intend to visit NO', 'Intend to visit SE',...
    'SE more - population', 'NO more - wealth',...
    'NO misuse money', 'SE will comply more',...
    'NO extend anyway', ...
    'SE more - national'};
EstimOpt.MeaMatrix = [1 0 0 0 0 0 0 0; ...
    0 1 0 0 0 0 0 0; ...
    0 0 1 0 0 0 0 0; ...
    0 0 0 1 0 0 0 0; ...
    0 0 0 0 1 0 0 0; ...
    0 0 0 0 0 1 0 0; ...
    0 0 0 0 0 0 1 0; ...
    0 0 0 0 0 0 0 1];
EstimOpt.MeaSpecMatrix = [2];

INPUT.Xmea = INPUT.Xmea(DATA.filter,:);

EstimOpt.FullCov = 0;

B_backup = [-3.5949495747655828559;3.351146257668608186;-1.7498267559895754886;0.083662451533268872295;7.3083211536787588969;3.6516846038244330508;1.1557805851168669875;1.2936292093983932094;0;0;-0.44298133034825537546;0;0;0;-1.0657466510484976396;0;0;0;0.54660575129822652762;0;0;0;0.67406984033264139011;0;0;0;-0.23528785604139954013;0;0;0;-1.1677661609057636838;0;0;0;-0.72418030870970173662;0;0;0;-1.39261320307172487;0;-0.69063569066698715648;-0.59660262184241585892;-0.8125284737990755568;0.46866521518231585297;-0.52256261140823812017;0.26181501029078146914;-0.49304539161369953515;-0.75821860948360952914;-0.34050498798329598138;-0.34849460941410642656;0.34514411459369026547;-1.105077055018310439;-0.47442536519825284635;0.014059775220308361882;-0.18597957333525155788;0.073783835708208261872;-0.77056174457105786058;-0.50889209075887720246;-0.074687475398587721553;-0.45708671451272586683;0.18473202697210355794;-1.1009722682030520513;-0.1926361326592455625;0.14096324632743820193;-0.41620028710261219862;-0.1104817632695422186;-1.677806705420445299;-0.27246984049215511314;0.24443355044048564739;-0.19447356827420786418;-0.51500999497643207281;-2.2481978873482950654;-0.53737129747499268184;0.58896626069211166499;-0.20561279387803249596;1.0553414443742699103;-2.1130150262253755145;-0.27014309779151651769;0.2814133052585400252;0.32849818019038501404];
EstimOpt.BActive = ones(size(B_backup));
EstimOpt.BActive([9,10,12, 13,14,16, 17,18,20, 21,22,24, 25,26,28, 29,30,32, 33,34,36, 37,38,40]) = 0;
B_backup = B_backup .* EstimOpt.BActive;

EstimOpt.RealMin = 0;

OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.HMXL_d = HMXL(INPUT,Results,EstimOpt,OptimOpt);
